## Tools

Contains custom tools written for CrewAI for now as part of the Agentic Framework, to make agents more powerful and extend their capabilities.

## Roadmap

Tools for the following platforms are on our roadmap:
- Contentful
- Agentic (allow delegation of task to other agentic nodes)
- Tealium
- SP Generate